@@ -89,13 +89,13 @@ class Kivy4(MDApp):
             self.appdata_path = app_data_path
             self.create_files(list_of_files)
 
-            self.icon = icon
             self.moon_icon = moon_icon
             self.sun_icon = sun_icon
             self.isDarkMode()
 
         self.theme_cls.primary_palette = main_color
         self.disable_x = disable_x
+        self.icon = icon
 
         screen = get_monitors()[0]
         self.width = screen.width
@@ -265,9 +265,14 @@ class Kivy4(MDApp):
 
     def getToolbar(self, properties: list):
         if properties == True:
-            properties = ['[]', '[[app.dark_mode_icon, lambda x: app.reverseDarkMode()]]']
+            right_icons, left_icons, name = '[[app.dark_mode_icon, lambda x: app.reverseDarkMode()]]', '[]', self.app_name
 
-        right_icons, left_icons = properties
+        elif len(properties) == 2:
+            left_icons, right_icons, name = properties[0], properties[1], self.app_name
+            name = self.app_name
+
+        else:
+            left_icons, right_icons, name = properties
 
         return f'''
 Screen:
@@ -275,7 +280,7 @@ Screen:
         id: toolbar
         pos_hint: {{"top": 1}}
         elevation: 10
-        title: "{self.app_name}"
+        title: "{משצק}"
         right_action_items: {right_icons}
         left_action_items: {left_icons}
     
